/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.formdata;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import lombok.NonNull;

public class FormDataUtils {

	final FormData baseFormData;
	final Map<String, Object> modifieableData;

	private FormDataUtils(FormData formData) {
		baseFormData = formData;
		modifieableData = new LinkedHashMap<>(formData.getFormData());
	}

	public static FormDataUtils from(FormData formData) {
		return new FormDataUtils(formData);
	}

	public FormDataUtils remove(String key) {
		modifieableData.remove(key);
		return this;
	}

	public FormDataUtils put(@NonNull String key, Object value) {
		modifieableData.put(key, value);
		return this;
	}

	public FormData.FormDataBuilder builder() {
		return baseFormData.toBuilder().formData(Collections.unmodifiableMap(modifieableData));
	}

	public FormData build() {
		return builder().build();
	}

	@SuppressWarnings("unchecked")
	public static Map<String, Object> getSubMap(FormData formData, String key) {
		return (Map<String, Object>) formData.getFormData().getOrDefault(key, Map.of());
	}
}
