/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.formdata;

import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import de.ozgcloud.eingang.common.formdata.FormData.FormDataControl;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class FormDataTestFactory {

	public static final Antragsteller ANTRAGSTELLER = AntragstellerTestFactory.create();
	public static final FormHeader HEADER = FormHeaderTestFactory.create();
	public static final String ID = UUID.randomUUID().toString();
	public static final String SIMPLE_VALUE_KEY = "kontaktsystemtypid";
	public static final String SIMPLE_VALUE = "233034600";

	public static final String SUBFORM_KEY = "zustaendigestelle";
	public static final String SUBKEY2 = "OrganisationseinheitenAuswahl";
	public static final String SUBVALUE2 = "9535669";
	public static final Map<String, String> SUBFORM_VALUE = Map.of(SUBKEY2, SUBVALUE2);

	public static final String NESTED_LIST_WITH_STRINGS_KEY = "nestedlist";
	public static final String NESTED_LIST_STRING_ELEMENT_1 = "n1";
	public static final String NESTED_LIST_STRING_ELEMENT_2 = "n2";
	public static final List<String> NESTED_LIST_WITH_STRINGS = List.of(NESTED_LIST_STRING_ELEMENT_1, NESTED_LIST_STRING_ELEMENT_2);

	public static final String NESTED_LIST_WITH_OBJECTS_KEY = "nestedlistwithobjects";
	public static final Map<String, Object> NESTED_LIST_OBJECTS_ELEMENT_1 = Map.of("o1", "o2");
	public static final Map<String, Object> NESTED_LIST_OBJECTS_ELEMENT_2 = Map.of("o3", "o4");
	public static final List<Map<String, Object>> NESTED_LIST_WITH_OBJECTS = List.of(NESTED_LIST_OBJECTS_ELEMENT_1, NESTED_LIST_OBJECTS_ELEMENT_2);

	public static final String VORGANG_ID = "vorgangId";

	public static final List<IncomingFileGroup> ATTACHMENTS = List.of(IncomingFileGroupTestFactory.create());
	public static final List<IncomingFile> REPRESENTATIONS = List.of(IncomingFileTestFactory.create());

	public static final FormDataControl FORM_DATA_CONTROL = FormDataControlTestFactory.create();

	public static final Map<String, Object> FORM_DATA = Map.of(
			SIMPLE_VALUE_KEY, SIMPLE_VALUE,
			SUBFORM_KEY, SUBFORM_VALUE,
			NESTED_LIST_WITH_STRINGS_KEY, NESTED_LIST_WITH_STRINGS,
			NESTED_LIST_WITH_OBJECTS_KEY, NESTED_LIST_WITH_OBJECTS);

	public static FormData create() {
		return createBuilder().build();
	}

	public static FormData.FormDataBuilder createBuilder() {
		return FormData.builder()
				.id(ID)
				.header(HEADER)
				.antragsteller(ANTRAGSTELLER)
				.zustaendigeStelle(ZustaendigeStelleTestFactory.create())
				.control(FORM_DATA_CONTROL)
				.formData(FORM_DATA)
				.numberOfAttachments(ATTACHMENTS.size())
				.attachments(ATTACHMENTS)
				.numberOfRepresentations(REPRESENTATIONS.size())
				.representations(REPRESENTATIONS);
	}

	@SafeVarargs
	public static FormData withFormDataMaps(Map<String, Object>... maps) {
		Map<String, Object> formData = new HashMap<>();

		Arrays.stream(maps).forEach(formData::putAll);

		return createBuilder().formData(Collections.unmodifiableMap(formData)).build();
	}
}
