/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.formdata;

import java.util.UUID;

import org.springframework.http.MediaType;
import org.springframework.mock.web.MockMultipartFile;

import de.ozgcloud.common.binaryfile.TempFileUtils;
import de.ozgcloud.eingang.common.formdata.IncomingFile.IncomingFileBuilder;
import lombok.SneakyThrows;

public class IncomingFileTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final String VENDOR_ID = "vendorId:xxx";
	public static final String NAME = "XML-Daten.xml";
	public static final String CONTENT_TYPE = "application/xml";
	public static final String PDF_CONTENT_TYPE = MediaType.APPLICATION_PDF_VALUE;
	public static final String JSON_CONTENT_TYPE = MediaType.APPLICATION_JSON_VALUE;
	public static final byte[] CONTENT = "TESTCONTENT1".getBytes();
	public static final long SIZE = 12;

	public static IncomingFile create() {
		return createBuilder().build();
	}

	public static IncomingFileBuilder createBuilder() {
		return IncomingFile.builder()
				.id(ID)
				.vendorId(VENDOR_ID)
				.name(NAME)
				.contentType(CONTENT_TYPE)
				.file(TempFileUtils.writeTmpFile(CONTENT))
				.size(SIZE);
	}

	public static MockMultipartFile asMultipartFile(String multipartName) {
		return asMultipartFile(multipartName, create());
	}

	@SneakyThrows
	public static MockMultipartFile asMultipartFile(String multipartName, IncomingFile file) {
		return new MockMultipartFile(multipartName, file.getName(), file.getContentType(), file.getContentStream().readAllBytes());
	}
}
