/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.enterprise.entry;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonProperty;

import lombok.Builder;
import lombok.Getter;
import lombok.extern.jackson.Jacksonized;

@Builder
@Getter
@Jacksonized
public class EntryData {

	private ControlData control;
	private List<EntryFormDataItem> formData;

	@Builder
	@Getter
	@Jacksonized
	public static class ControlData {
		private String transactionId;
		private String zustaendigeStelle;
		private String[] leikaIds;
		private ResultEndpoint resultEndpoint;
		private String formId;
		@JsonProperty("name")
		private String formName;
		private Servicekonto serviceKonto;

		private Representations representations;

		@Builder
		@Getter
		@Jacksonized
		public static class ResultEndpoint {
			private String address;
		}

		@Builder
		@Getter
		@Jacksonized
		public static class Representations {
			private String formData;
			private String formDataModell;
		}
	}

	@Builder
	@Getter
	@Jacksonized
	public static class Servicekonto {
		private String type;
		private PostfachAddress postfachAddress;
	}

	@Builder
	@Getter
	@Jacksonized
	public static class PostfachAddress {
		private String identifier;
		private String type;
	}
}
