/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.enterprise.entry;

import de.ozgcloud.eingang.enterprise.entry.EntryData.ControlData;
import de.ozgcloud.eingang.enterprise.entry.EntryData.ControlData.Representations;
import de.ozgcloud.eingang.enterprise.entry.EntryData.ControlData.ResultEndpoint;

public class ControlDataTestFactory {

	public static final String TRANSACTION_ID = "4e7a6ae7-4d0f-444d-8971-7cfc051c9924";
	public static final String ZUSTAENDIGE_STELLE = "248240886";
	public static final String[] LEIKA_IDS = new String[] { "99108011000000", "99108011153000" };

	public static final String RESULT_ENDPOIN_ADDRESS = "https://idalabs.de/backend/api";

	public static final String FORM_ID = "KFAS_LIVE_KI_10_Haltverbot_befristet";
	public static final String NAME = "Anmeldung zur Einrichtung einer zeitlich befristeten Haltverbotszone gem. § 45 Abs. 1 Straßenverkehrsordnung (StVO)";

	public static ControlData create() {
		return createBuilder().build();
	}

	public static ControlData.ControlDataBuilder createBuilder() {
		return ControlData.builder()
				.transactionId(TRANSACTION_ID)
				.zustaendigeStelle(ZUSTAENDIGE_STELLE)
				.leikaIds(LEIKA_IDS)
				.resultEndpoint(ResultEndpoint.builder().address(RESULT_ENDPOIN_ADDRESS).build())
				.formId(FORM_ID)
				.formName(NAME)
				.serviceKonto(ServicekontoTestFactory.create())
				.representations(Representations.builder()
						.formData(FormDataControlTestFactory.PRIMARY_FORM_DATA_REPRESENTATION)
						.formDataModell(FormDataControlTestFactory.FORM_DATA_MODELL)
						.build());
	}
}
