/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.Map;
import java.util.Optional;

import org.apache.commons.collections.MapUtils;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.Antragsteller;
import de.ozgcloud.eingang.common.formdata.FormData;

@Component
class AntragstellerMapper implements FimEngineBasedMapper {

	static final String ANTRAGSTELLER_KEY = "G17002112";

	static final String ANSCHRIFT_KEY = "G60000086";

	static final String VORNAME_KEY = "F60000228";
	static final String NACHNAME_KEY = "F60000227";
	static final String EMAIL_KEY = "F60000242";
	static final String STRASSE_KEY = "F60000243";
	static final String HAUSNUMMER_KEY = "F60000244";
	static final String PLZ_KEY = "F60000246";
	static final String ORT_KEY = "F60000247";

	@Override
	public FormData parseFormData(FormData formData) {
		return Optional.ofNullable(getAntragsteller(formData.getFormData()))
				.filter(MapUtils::isNotEmpty)
				.map(this::mapAntragsteller)
				.map(antragsteller -> formData.toBuilder().antragsteller(antragsteller).build()).orElse(formData);
	}

	Map<String, Object> getAntragsteller(Map<String, Object> formData) {
		return FimDataUtil.getValueMapByKey(formData, ANTRAGSTELLER_KEY);
	}

	Antragsteller mapAntragsteller(Map<String, Object> antragsteller) {
		var anschrift = getAnschrift(antragsteller);

		return Antragsteller.builder()
				.vorname(FimDataUtil.getValueByKey(antragsteller, VORNAME_KEY).orElse(null))
				.nachname(FimDataUtil.getValueByKey(antragsteller, NACHNAME_KEY).orElse(null))
				.email(FimDataUtil.getValueByKey(antragsteller, EMAIL_KEY).orElse(null))
				.strasse(FimDataUtil.getValueByKey(anschrift, STRASSE_KEY).orElse(null))
				.hausnummer(FimDataUtil.getValueByKey(anschrift, HAUSNUMMER_KEY).orElse(null))
				.plz(FimDataUtil.getValueByKey(anschrift, PLZ_KEY).orElse(null))
				.ort(FimDataUtil.getValueByKey(anschrift, ORT_KEY).orElse(null))
				.build();
	}

	private Map<String, Object> getAnschrift(Map<String, Object> antragsteller) {
		return FimDataUtil.getValueMapByKey(antragsteller, ANSCHRIFT_KEY);
	}
}