/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

import org.apache.commons.collections4.MapUtils;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
class FimDataUtil {

	static final String VALUE_KEY = "value";

	public static Optional<String> getValue(Map<String, Object> data, List<String> pathKeys, String key) {
		var current = FimDataUtil.getSubmap(data, pathKeys);
		if (Objects.isNull(current)) {
			return Optional.empty();
		}
		return FimDataUtil.getValueByKey(current, key);
	}

	private static Map<String, Object> getSubmap(Map<String, Object> data, List<String> pathKeys) {
		var current = data;
		for (var pathKey : pathKeys) {
			current = FimDataUtil.getValueMapByKey(current, pathKey);
		}
		return current;
	}

	static Map<String, Object> getValueMapByKey(Map<String, Object> obj, String key) {
		return Optional.ofNullable(MapUtils.getMap(obj, key))
				.map(FimDataUtil::castToMap)
				.map(FimDataUtil::getValueAsMap)
				.orElse(null);
	}

	public static Optional<String> getValueByKey(Map<String, Object> data, String key) {
		var map = FimDataUtil.castToMap(MapUtils.getMap(data, key));
		return Optional.ofNullable(MapUtils.getString(map, VALUE_KEY));
	}

	@SuppressWarnings("unchecked")
	private static Map<String, Object> castToMap(Map<?, ?> obj) {
		return (Map<String, Object>) obj;
	}

	private static Map<String, Object> getValueAsMap(Map<String, Object> map) {
		return FimDataUtil.castToMap(MapUtils.getMap(map, VALUE_KEY));
	}
}