/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Optional;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

import de.ozgcloud.eingang.fim.common.xml.DocumentHelper;
import lombok.Getter;

class FimScheme {

	private final Document doc;
	@Getter
	private final FimSchemeIdentifier identifier;

	@Getter
	private final FimSchemeAdapter schemeAdapter;
	private final Map<String, Element> fieldIndex = new LinkedHashMap<>();

	public FimScheme(Document doc, FimSchemeIdentifier identifier, FimSchemeAdapter schemeAdapter) {
		this.doc = doc;
		this.identifier = identifier;
		this.schemeAdapter = schemeAdapter;

		buildFieldIndex();
	}

	private void buildFieldIndex() {
		DocumentHelper.getChildNodes(getElements()).forEach(group -> fieldIndex.put(getName(group), group));
	}

	private NodeList getElements() {
		return doc.getElementsByTagName("xs:element");
	}

	private String getName(Element element) {
		return element.getAttribute("name");
	}

	Optional<String> getFieldName(String fieldName) {
		return schemeAdapter.getFieldName(fieldIndex, fieldName);
	}
}
