/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.List;

import jakarta.annotation.PostConstruct;

import org.springframework.core.io.ResourceLoader;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Component
class FimSchemeHelper {

	private final FimProperties fimProperties;
	private final ResourceLoader resourceLoader;
	private final List<FimSchemeAdapter> fimSchemeAdapters;

	private FimSchemeAdapterCatalogue schemeAdapterCatalogue;
	private FimSchemeCatalogue schemeCatalogue;

	@PostConstruct
	void init() {
		initSchemeAdapterCatalogue();
		initSchemeCatalogue();
	}

	private void initSchemeAdapterCatalogue() {
		schemeAdapterCatalogue = new FimSchemeAdapterCatalogue();

		fimSchemeAdapters.forEach(adapter -> schemeAdapterCatalogue.put(adapter.getIdentifier(), adapter));
	}

	private void initSchemeCatalogue() {
		schemeCatalogue = new FimSchemeCatalogue(fimProperties, resourceLoader, schemeAdapterCatalogue);
	}

	public FimScheme getScheme(String identifier) {
		return schemeCatalogue.get(FimSchemeIdentifier.fromString(identifier));
	}

	public FimScheme getDefaultScheme() {
		return schemeCatalogue.get(UnknownSchemeAdapter.IDENTIFIER);
	}
}