/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.List;
import java.util.Map;
import java.util.Optional;

import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.FormData;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@RequiredArgsConstructor
@Component
class HeaderMapper implements FimEngineBasedMapper {

	static final String FORM_NAME_KEY = "F05002753";

	@Override
	public FormData parseFormData(FormData formData) {
		return getFormName(formData.getFormData()).map(formName -> addFormName(formData, formName)).orElse(formData);
	}

	Optional<String> getFormName(Map<String, Object> formData) {
		return FimDataUtil.getValue(formData, List.of("G17003529", "G05001479", "G05001480"), FORM_NAME_KEY);
	}

	private FormData addFormName(FormData formData, String formName) {
		return formData.toBuilder()
				.header(formData.getHeader().toBuilder()
						.formName(formName)
						.build())
				.build();
	}
}