/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.List;
import java.util.Objects;
import java.util.Optional;

import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.ZustaendigeStelle;
import lombok.NonNull;

@Component
class ZustaendigeStelleMapper implements FimEngineBasedMapper {

	static final String XTA_IDENTIFIER_ENTRY_NAME = "xtaIdentifier";

	// TODO OZG-7086 umstellen auf FIM Headerdaten

	@Override
	public FormData parseFormData(FormData formData) {
		return formData.getControl().getMetaData()
				.map(metaData -> metaData.getEntry(XTA_IDENTIFIER_ENTRY_NAME))
				.filter(Objects::nonNull)
				.map(id -> setOrganisationEinheitId(formData.getZustaendigeStelles(), id))
				.map(zustStelle -> formData.toBuilder().zustaendigeStelle(zustStelle).build())
				.orElse(formData);
	}

	private ZustaendigeStelle setOrganisationEinheitId(List<ZustaendigeStelle> stellen, @NonNull String organisationEinheitId) {
		var builder = stellen.isEmpty() ? ZustaendigeStelle.builder() : stellen.getFirst().toBuilder();

		extractOrganisationEinheitId(organisationEinheitId).ifPresent(builder::organisationseinheitenId);
		return builder.build();
	}

	Optional<String> extractOrganisationEinheitId(@NonNull String xtaIdentifier) {
		var idx = xtaIdentifier.indexOf(":");
		if (idx < 0) {
			return Optional.empty();
		}
		return Optional.of(xtaIdentifier.substring(idx + 1));
	}
}
