/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.util.HashMap;
import java.util.Map;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.eingang.common.formdata.Antragsteller;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class AntragstellerTestFactory {

	public static final String VORNAME = LoremIpsum.getInstance().getWords(1);
	public static final String NACHNAME = LoremIpsum.getInstance().getWords(1);
	public static final String EMAIL = LoremIpsum.getInstance().getEmail();
	public static final String STRASSE = LoremIpsum.getInstance().getName();
	public static final String HAUSNUMMER = "4a";
	public static final String PLZ = LoremIpsum.getInstance().getZipCode();
	public static final String ORT = LoremIpsum.getInstance().getCity();

	public static Antragsteller create() {
		return createBuilder().build();
	}

	public static Antragsteller.AntragstellerBuilder createBuilder() {
		return Antragsteller.builder()
				.vorname(VORNAME)
				.nachname(NACHNAME)
				.email(EMAIL)
				.strasse(STRASSE)
				.hausnummer(HAUSNUMMER)
				.plz(PLZ)
				.ort(ORT);
	}

	public static Map<String, Object> createAntragstellerAsFimMap() {
		return Map.of(
				AntragstellerMapper.VORNAME_KEY, Map.of(FimDataUtil.VALUE_KEY, VORNAME),
				AntragstellerMapper.NACHNAME_KEY, Map.of(FimDataUtil.VALUE_KEY, NACHNAME),
				AntragstellerMapper.EMAIL_KEY, Map.of(FimDataUtil.VALUE_KEY, EMAIL),
				AntragstellerMapper.ANSCHRIFT_KEY, createAnschriftAsFimMap());
	}

	private static Map<String, Object> createAnschriftAsFimMap() {
		var anschrift = new HashMap<String, Object>();
		anschrift.put(FimDataUtil.VALUE_KEY, Map.of(
				AntragstellerMapper.STRASSE_KEY, Map.of(FimDataUtil.VALUE_KEY, STRASSE),
				AntragstellerMapper.HAUSNUMMER_KEY, Map.of(FimDataUtil.VALUE_KEY, HAUSNUMMER),
				AntragstellerMapper.PLZ_KEY, Map.of(FimDataUtil.VALUE_KEY, PLZ),
				AntragstellerMapper.ORT_KEY, Map.of(FimDataUtil.VALUE_KEY, ORT)));
		return anschrift;
	}
}