/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import static org.assertj.core.api.Assertions.*;

import java.util.Collections;
import java.util.Map;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class FimDataUtilTest {

	@DisplayName("Get value as key")
	@Nested
	class TestGetValueAsKey {

		private final String fieldKey = "fieldKey";

		private final Map<String, Object> valueDataMap = Collections.singletonMap("valueDataKey", "valueDataValue");
		private final Map<String, Object> valueMap = Collections.singletonMap(FimDataUtil.VALUE_KEY, valueDataMap);
		private final Map<String, Object> fieldMap = Collections.singletonMap(fieldKey, valueMap);

		@Test
		void shouldReturNullOnNullMap() {
			var map = FimDataUtil.getValueMapByKey(null, fieldKey);

			assertThat(map).isNull();
		}

		@Test
		void shouldReturnNullOnNullKeyValue() {
			var map = FimDataUtil.getValueMapByKey(fieldMap, null);

			assertThat(map).isNull();
		}

		@Test
		void shouldReturnValueMapEntry() {
			var map = FimDataUtil.getValueMapByKey(fieldMap, fieldKey);

			assertThat(map).isEqualTo(valueDataMap);
		}
	}
}