/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.fim;

import java.io.File;
import java.util.Map;

import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;

import lombok.SneakyThrows;

public class FimDocumentTestHelper {

	private static final String RESOURCE_PATH = "src/test/resources/";

	public static Document getTest1Document() {
		return loadDocument("test1.xml");
	}

	public static Document getTest2Document() {
		return loadDocument("test2.xml");
	}

	public static Map<String, Object> getTest2AsMap() {
		return Map.of(
				"fim.S1235", Map.of("label", "Testkey", "value", "Testvalue"),
				"fim.S1236", Map.of("label", "fim.S1236", "value", "Testvalue 2"));
	}

	public static Document getTest3Document() {
		return loadDocument("test3.xml");
	}

	public static Map<String, Object> getTest3AsMap() {
		return Map.of(
				"fim.S1235", Map.of("label", "Testkey", "value", "Testvalue"),
				"fim.S1236", Map.of("label", "fim.S1236", "value", "Testvalue 2"));
	}

	public static Document getVersammlungsAnzeigeDocument() {
		return loadDocument("S17000652V1.4_test01.xml");
	}

	public static Map<String, Object> getVersammlungsAnzeigeAsMap() {
		return Map.of(
				"G17003529", Map.of(
						"label", "EfA|SH Standard",
						"value", Map.of(
								"G05001479", Map.of(
										"label", "nachrichtenkopf",
										"value", Map.of(
												"G05001480", Map.of(
														"label", "identifikation.nachricht",
														"value", Map.of(
																"F05002750",
																Map.of("label", "nachrichtenUUID", "value", "d447e43a-5723-4821-a170-cb44d2dbf143"),
																"F05002751",
																Map.of("label", "erstellungszeitpunkt", "value", "2022-08-15T09:30:47"),
																"F05002752",
																Map.of("label", "nachrichtentyp", "value", "fim.S17000652.17000652001004"),
																"F05002753",
																Map.of("label", "dienstname", "value", "urn:fim:Versammlungsanzeige:1.4"))),
												"G05001481", Map.of(
														"label", "Leser",
														"value", Map.of(
																"F05002754", Map.of("label", "Organisationsname", "value", "Celle"),
																"F05002755",
																Map.of("label", "Organisationsschlüssel", "value", "vbe:010550120100"),
																"F05002756", Map.of("label", "Kategorie", "value", "Versammlungsbehörde"))),
												"G05001482", Map.of(
														"label", "Autor",
														"value", Map.of(
																"F05002754",
																Map.of("label", "Organisationsname", "value",
																		"OSI-Onlinedienst Niedersachsen Versammlungsanzeige"),
																"F05002755",
																Map.of("label", "Organisationsschlüssel", "value", "vbe:010550120100"),
																"F05002756",
																Map.of("label", "Kategorie", "value", "Engagement- und Hobbyportal"))))),
								"F17005454", Map.of("label", "Datenschutzhinweis DSGVO", "value", "true"),
								"F17005455", Map.of("label", "Zustimmung zu einem digitalen Bescheid", "value", "true"),
								"F17005533", Map.of("label", "UUID", "value", "String"))),
				"F17009191", Map.of("label", "Anzeige durch Person", "value", "true"),
				"F17003371", Map.of("label", "Anzeigenart", "value", "String"));
	}

	public static Document getAntragDocument() {
		return loadDocument("antrag.xml");
	}

	@SneakyThrows
	private static Document loadDocument(String fileName) {
		return DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(new File(RESOURCE_PATH + fileName));
	}
}