/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formcycle;

import java.util.Collection;
import java.util.Map;
import java.util.stream.Collectors;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.safety.Safelist;
import org.springframework.stereotype.Component;
import org.springframework.web.util.HtmlUtils;

import de.ozgcloud.eingang.common.formdata.FormData;

@Component
public class FormDataHtmlCleaner {

	public FormData clean(FormData formData) {
		return formData.toBuilder().formData(cleanFormData(formData.getFormData())).build();
	}

	Map<String, Object> cleanFormData(Map<String, Object> formData) {
		return formData.entrySet().stream().collect(Collectors.toMap(Map.Entry::getKey, entry -> cleanValue(entry.getValue())));
	}

	@SuppressWarnings("unchecked")
	Object cleanValue(Object value) {
		if (value instanceof Map) {
			return cleanFormData((Map<String, Object>) value);
		} else if (value instanceof Collection<?> values) {
			return values.stream().map(this::cleanValue).toList();
		} else if (value instanceof String valueString) {
			return parseHtml(valueString);
		}
		return value;
	}

	String parseHtml(String html) {
		var outputSettings = new Document.OutputSettings(); // keep new lines
		outputSettings.prettyPrint(false);
		var htmlText = Jsoup.clean(replaceNewLines(html), "", Safelist.none(), outputSettings);
		return HtmlUtils.htmlUnescape(htmlText);
	}

	private String replaceNewLines(String html) {
		return html.replace("\\\\n", "\n");
	}
}
