/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formcycle;

import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.TimeZone;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.http.MediaType;
import org.springframework.http.converter.protobuf.ProtobufHttpMessageConverter;

import de.ozgcloud.eingang.formcycle.common.errorhandling.FormcycleExceptionHandler;
import de.ozgcloud.eingang.formcycle.common.protobuf.CustomProtobufHttpMessageConverter;
import de.ozgcloud.eingang.semantik.enginebased.EngineBasedSemantikAdapter;
import de.ozgcloud.eingang.semantik.enginebased.formcycle.FormCycleEngineBasedAdapter;

@SpringBootApplication(scanBasePackages = { "de.ozgcloud" })
public class FormcycleAdapterApplication {

	public static void main(String[] args) {
		TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
		SpringApplication.run(FormcycleAdapterApplication.class, args);
	}

	@Bean
	EngineBasedSemantikAdapter engineBasedAdapter() {
		return new FormCycleEngineBasedAdapter();
	}

	@Bean
	ProtobufHttpMessageConverter protobufMessageConverter() {
		return addCustomProtobufMediaType(new CustomProtobufHttpMessageConverter());
	}

	@Deprecated(forRemoval = true, since = "2.1.0")
	// FIXME: Remove this method after all customers have updated ozg-cloud plugin to version 1.4.0 or higher
	private ProtobufHttpMessageConverter addCustomProtobufMediaType(ProtobufHttpMessageConverter protobufHttpMessageConverter) {
		var supportetMediaTypes = new ArrayList<>(protobufHttpMessageConverter.getSupportedMediaTypes());
		supportetMediaTypes.add(new MediaType("application", "protobuf", StandardCharsets.UTF_8));
		protobufHttpMessageConverter.setSupportedMediaTypes(supportetMediaTypes);
		return protobufHttpMessageConverter;
	}

	@Bean
	FormcycleExceptionHandler restResposeEntityExceptionHandler() {
		return new FormcycleExceptionHandler();
	}
}
