/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formcycle;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import de.ozgcloud.eingang.common.formdata.FormHeaderTestFactory;
import de.ozgcloud.eingang.common.formdata.ZustaendigeStelle;
import de.ozgcloud.vorgang.common.grpc.GrpcFormDataMapper;

class FormCycleFormDataMapperTest {

	@InjectMocks
	private FormCycleFormDataMapper mapper = Mappers.getMapper(FormCycleFormDataMapper.class);

	@Spy
	private GrpcFormDataMapper formDataMapper = Mappers.getMapper(GrpcFormDataMapper.class);

	@Nested
	class TestToFormData {

		@Test
		void shouldMapHeader() {
			var expectedFormHeader = FormHeaderTestFactory.create();

			var mapped = mapper.toFormData(FormCycleFormDataTestFactory.create());

			assertThat(mapped.getHeader()).usingRecursiveComparison()
					.ignoringFields("vorgangNummer", "sender", "formEngineName", "serviceKonto").isEqualTo(expectedFormHeader);
		}

		@Test
		void shouldMapZustaendigeStelle() {
			var mapped = mapper.toFormData(FormCycleFormDataTestFactory.create());

			assertThat(mapped.getZustaendigeStelles())
					.extracting(ZustaendigeStelle::getOrganisationseinheitenId)
					.containsExactly(FormCycleFormHeaderTestFactory.ORGANISATIONSEINHEIT_ID);
		}
	}

}
