/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.formcycle;

import static org.assertj.core.api.Assertions.*;

import java.util.Map;

import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;

class FormDataHtmlCleanerITCase {

	@Spy
	@InjectMocks
	private FormDataHtmlCleaner cleaner;

	static final String KEY_LABEL = "label";
	static final String KEY_VALUE = "value";

	static final Map<String, Object> FORM_DATA_MAP = Map.of("tf1", Map.of(
					KEY_LABEL, "<p><em>Label</em></p>",
					KEY_VALUE, "<i>Value</i>"),
			"fs1", Map.of(
					KEY_LABEL, "Key",
					KEY_VALUE, Map.of(
							"tf3", Map.of(
									KEY_LABEL, "<p><s>Label</s></p>",
									KEY_VALUE, "ein Text mit <html><body><h1>Hello</h1><body><html>")),
					"tf4", Map.of(
							KEY_LABEL, "<p><span style=\"background-color:#1abc9c;\">Wichtig</span></p>",
							KEY_VALUE, "Text"),
					"ed1", Map.of(
							KEY_LABEL,
							"<ol>\n\t<li><em><strong><u>ganz</u></strong></em></li>\n\t<li><span style=\"color:#e74c3c;"
									+ "\">bunt</span></li>\n</ol>",
							KEY_VALUE, "TExt\nmit\n    Leerzeichen\nund\n  Umbrüchen"
					)));

	static final Map<String, Object> EXPECTED_MAP = Map.of("tf1", Map.of(
					KEY_LABEL, "Label",
					KEY_VALUE, "Value"),
			"fs1", Map.of(
					KEY_LABEL, "Key",
					KEY_VALUE, Map.of(
							"tf3", Map.of(
									KEY_LABEL, "Label",
									KEY_VALUE, "ein Text mit Hello")),
					"tf4", Map.of(
							KEY_LABEL, "Wichtig",
							KEY_VALUE, "Text"),
					"ed1", Map.of(
							KEY_LABEL,
							"\n\tganz\n\tbunt\n",
							KEY_VALUE, "TExt\nmit\n    Leerzeichen\nund\n  Umbrüchen"
					)));

	@Test
	void shouldCleanHtml() {
		var result = cleaner.clean(FormDataTestFactory.createBuilder().formData(FORM_DATA_MAP).build());

		assertThat(result.getFormData()).usingRecursiveComparison().isEqualTo(EXPECTED_MAP);
	}

}