/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.forwarder;

import java.io.File;
import java.io.InputStream;
import java.util.concurrent.CompletableFuture;

import de.ozgcloud.eingang.forwarding.GrpcRouteForwardingRequest;
import de.ozgcloud.eingang.forwarding.GrpcRouteForwardingResponse;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
@RequiredArgsConstructor
public class RouteForwardingGrpcService extends RouteForwardingServiceGrpc.RouteForwardingServiceImplBase {

	private final RouteForwardingMapper routeForwardingMapper;
	private final IncomingFileMapper incomingFileMapper;
	private final IncomingFileGroupMapper incomingFileGroupMapper;
	private final RouteForwardingService routeForwardingService;
	private final FileService fileService;

	@Override
	public StreamObserver<GrpcRouteForwardingRequest> routeForwarding(StreamObserver<GrpcRouteForwardingResponse> responseObserver) {
		return EingangStubReceiverStreamObserver.builder()
				.fileSaver(this::saveFile)
				.routeForwardingMapper(routeForwardingMapper)
				.incomingFileMapper(incomingFileMapper)
				.incomingFileGroupMapper(incomingFileGroupMapper)
				.formDataConsumer(routeForwardingService::route)
				.responseConsumer(repsonse -> respondWith(responseObserver, repsonse))
				.build();
	}

	public CompletableFuture<File> saveFile(InputStream inputStream) {
		return fileService.saveToFile(inputStream);
	}

	public void respondWith(StreamObserver<GrpcRouteForwardingResponse> responseObserver, GrpcRouteForwardingResponse response) {
		responseObserver.onNext(response);
		responseObserver.onCompleted();
	}

}
