/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.forwarder;

import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;

import de.ozgcloud.eingang.common.formdata.Antragsteller;
import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.ZustaendigeStelle;
import de.ozgcloud.eingang.forwarding.GrpcRouteCriteria;
import de.ozgcloud.eingang.forwarding.GrpcRouteForwarding;
import de.ozgcloud.eingang.router.ServiceKontoMapper;
import de.ozgcloud.vorgang.common.grpc.GrpcFormDataMapper;
import de.ozgcloud.vorgang.vorgang.GrpcAntragsteller;

@Mapper(nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, //
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, //
		uses = { ServiceKontoMapper.class, GrpcFormDataMapper.class })
public interface RouteForwardingMapper {

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "attachment", ignore = true)
	@Mapping(target = "attachments", ignore = true)
	@Mapping(target = "numberOfAttachments", ignore = true)
	@Mapping(target = "representation", ignore = true)
	@Mapping(target = "representations", ignore = true)
	@Mapping(target = "numberOfRepresentations", ignore = true)
	@Mapping(target = "control", ignore = true)
	@Mapping(target = "zustaendigeStelles", ignore = true)
	@Mapping(target = ".", source = "eingangStub")
	@Mapping(target = "zustaendigeStelle", source = "routeCriteria")
	FormData toFormData(GrpcRouteForwarding routeForwarding);

	@Mapping(target = "data", source = "otherData")
	Antragsteller mapAntragstellerFromGrpc(GrpcAntragsteller antragsteller);

	default ZustaendigeStelle toZustaendigeStelle(GrpcRouteCriteria routeCriteria) {
		return ZustaendigeStelle.builder().organisationseinheitenId(routeCriteria.getOrganisationEinheitId()).build();
	}
}
