/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.forwarder;

import de.ozgcloud.eingang.common.formdata.AntragstellerTestFactory;
import de.ozgcloud.vorgang.vorgang.GrpcAntragsteller;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;
import de.ozgcloud.vorgang.vorgang.GrpcFormField;
import de.ozgcloud.vorgang.vorgang.GrpcSubForm;

public class GrpcAntragstellerTestFactory {

	public static final String ANREDE = AntragstellerTestFactory.ANREDE;
	public static final String NACHNAME = AntragstellerTestFactory.NACHNAME;
	public static final String VORNAME = AntragstellerTestFactory.VORNAME;
	public static final String GEBURTSDATUM = AntragstellerTestFactory.GEBURTSDATUM;
	public static final String GEBURTSORT = AntragstellerTestFactory.GEBURTSORT;
	public static final String GEBURTSNAME = AntragstellerTestFactory.GEBURTSNAME;
	public static final String EMAIL = AntragstellerTestFactory.EMAIL;
	public static final String TELEFON = AntragstellerTestFactory.TELEFON;
	public static final String STRASSE = AntragstellerTestFactory.STRASSE;
	public static final String HAUSNUMMER = AntragstellerTestFactory.HAUSNUMMER;
	public static final String PLZ = AntragstellerTestFactory.PLZ;
	public static final String ORT = AntragstellerTestFactory.ORT;

	public static final String POSTFACH_ID = AntragstellerTestFactory.POSTFACH_ID;
	public static final GrpcFormData OTHER_DATA = GrpcFormData.newBuilder()
			.addField(GrpcFormField.newBuilder()
					.setName(AntragstellerTestFactory.GEBIET_BEZEICHNUNG_KEY)
					.setValue(AntragstellerTestFactory.GEBIET_BEZEICHNUNG_VALUE).build())
			.addForm(GrpcSubForm.newBuilder().setTitle(AntragstellerTestFactory.SUB_PERSOENLICHE_EIGNUNG)
					.addField(GrpcFormField.newBuilder()
							.setName(AntragstellerTestFactory.SUB_VERBOTENE_VEREINIGUNG_KEY)
							.setValue(AntragstellerTestFactory.SUB_VERBOTENE_VEREINIGUNG_VALUE).build())
					.build())
			.build();

	public static GrpcAntragsteller create() {
		return createBuilder().build();
	}

	public static GrpcAntragsteller.Builder createBuilder() {
		return GrpcAntragsteller.newBuilder()
				.setAnrede(ANREDE)
				.setFirmaName(AntragstellerTestFactory.FIRMA_NAME)
				.setGeburtsdatum(GEBURTSDATUM)
				.setNachname(NACHNAME)
				.setVorname(VORNAME)
				.setGeburtsname(GEBURTSNAME)
				.setGeburtsort(GEBURTSORT)
				.setEmail(EMAIL)
				.setTelefon(TELEFON)
				.setStrasse(STRASSE)
				.setHausnummer(HAUSNUMMER)
				.setPlz(PLZ)
				.setOrt(ORT)
				.setPostfachId(POSTFACH_ID)
				.setOtherData(OTHER_DATA);
	}
}