/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.zufi;

import org.springframework.stereotype.Service;

import de.ozgcloud.eingang.Application;
import de.ozgcloud.eingang.router.errorhandling.MultipleOrganisationsEinheitenException;
import de.ozgcloud.eingang.router.errorhandling.UnknownOrganisationseinheitException;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcGetByOrganisationsEinheitIdRequest;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcGetByOrganisationsEinheitIdResponse;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheit;
import de.ozgcloud.zufi.grpc.organisationseinheit.OrganisationsEinheitServiceGrpc.OrganisationsEinheitServiceBlockingStub;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
@RequiredArgsConstructor
class OrganisationsEinheitRemoteService {

	@GrpcClient(Application.ZUFI_MANAGER_GRPC_CLIENT)
	private final OrganisationsEinheitServiceBlockingStub serviceStub;
	private final OrganisationsEinheitMapper mapper;

	public OrganisationsEinheit getByOrganisationEinheitId(String id) {
		var response = serviceStub
				.getByOrganisationsEinheitId(GrpcGetByOrganisationsEinheitIdRequest.newBuilder().setOrganisationsEinheitId(id).build());
		verifyResponse(id, response);
		return mapper.fromGrpc(getOrganisationEinheit(response));
	}

	void verifyResponse(String id, GrpcGetByOrganisationsEinheitIdResponse response) {
		if (response.getOrganisationsEinheitenCount() > 1) {
			throw new MultipleOrganisationsEinheitenException(id);
		}
		if (response.getOrganisationsEinheitenCount() == 0) {
			throw new UnknownOrganisationseinheitException();
		}
	}

	private GrpcOrganisationsEinheit getOrganisationEinheit(GrpcGetByOrganisationsEinheitIdResponse response) {
		return response.getOrganisationsEinheitenList().getFirst();
	}
}
