/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.router;

import java.util.Objects;
import java.util.concurrent.TimeUnit;

import de.ozgcloud.eingang.common.errorhandling.TechnicalException;
import io.grpc.ManagedChannel;
import io.grpc.stub.AbstractStub;
import lombok.Builder;

@Builder
class ClosableStub<T extends AbstractStub<?>> implements ManagableStub<T> {

	private static final int SHUTDOWN_TIME_IN_SEC = 3;

	private T stub;
	private ManagedChannel channel;

	@Override
	public T get() {
		return stub;
	}

	public void close() {
		if (Objects.nonNull(stub)) {
			shutdownChannel();
			stub = null;
		}
	}

	private void shutdownChannel() {
		try {
			channel.shutdown().awaitTermination(ClosableStub.SHUTDOWN_TIME_IN_SEC, TimeUnit.SECONDS);
		} catch (InterruptedException e) {
			Thread.currentThread().interrupt();
			throw new TechnicalException("Error shutting down grpc channel.", e);
		}
	}

	@Override
	public boolean isShutdownable() {
		return true;
	}
}