/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.router;

import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.mapstruct.CollectionMappingStrategy;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.ReportingPolicy;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.eingang.common.formdata.PostfachAddressIdentifier;
import de.ozgcloud.eingang.common.formdata.ServiceKonto;
import de.ozgcloud.eingang.common.formdata.StringBasedIdentifier;
import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.vorgang.GrpcServiceKonto;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN, //
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE, //
		nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, //
		collectionMappingStrategy = CollectionMappingStrategy.ADDER_PREFERRED, //
		uses = { GrpcObjectMapper.class })
public abstract class ServiceKontoMapper {

	static final String DEFAULT_TRUST_LEVEL = "STORK-QAA-Level-1";

	@Autowired
	private GrpcObjectMapper grpcObjectMapper;

	@Mapping(target = "postfachAddressesList", source = "postfachAddresses")
	@Mapping(target = "trustLevel", source = "trustLevel", defaultValue = DEFAULT_TRUST_LEVEL)
	abstract GrpcServiceKonto toGrpc(ServiceKonto serviceKonto);

	GrpcObject mapFromIdentifier(PostfachAddressIdentifier identifier) {
		return grpcObjectMapper.fromMap(Map.of(StringBasedIdentifier.POSTFACH_ID_FIELD,
				getStringBasedValue(identifier)));
	}

	String getStringBasedValue(PostfachAddressIdentifier identifier) {
		return ((StringBasedIdentifier) identifier).getPostfachId();
	}

	@Mapping(target = "postfachAddresses", source = "postfachAddressesList")
	@Mapping(target = "trustLevel", source = "trustLevel", qualifiedByName = "mapTrustLevel")
	@Mapping(target = "postfachAddress", ignore = true)
	public abstract ServiceKonto fromGrpc(GrpcServiceKonto serviceKonto);

	PostfachAddressIdentifier mapToIdentifier(GrpcObject identifier) {
		var stringIdentifier = MapUtils.getString(grpcObjectMapper.mapFromGrpc(identifier), StringBasedIdentifier.POSTFACH_ID_FIELD);
		return StringBasedIdentifier.builder().postfachId(stringIdentifier).build();
	}

	@Named("mapTrustLevel")
	String mapTrustLevel(String trustLevel) {
		if (StringUtils.isEmpty(trustLevel)) {
			return DEFAULT_TRUST_LEVEL;
		}
		return trustLevel;
	}

}