/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.common.zufi;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class ZufiServiceTest {

	@InjectMocks
	private ZufiService service;
	@Mock
	private OrganisationsEinheitRemoteService remoteService;

	@DisplayName("Get vorgangManager url")
	@Nested
	class TestGetVorgangManagerUrl {

		private final OrganisationsEinheit organisationsEinheit = OrganisationsEinheitTestFactory.create();

		@BeforeEach
		void mock() {
			when(remoteService.getByOrganisationEinheitId(any())).thenReturn(organisationsEinheit);
		}

		@Test
		void shouldCallRemoteService() {
			service.getVorgangManagerUrl(OrganisationsEinheitTestFactory.ID);

			verify(remoteService).getByOrganisationEinheitId(OrganisationsEinheitTestFactory.ID);
		}

		@Test
		void shouldReturnValue() {
			var vorgangManagerAddress = service.getVorgangManagerUrl(OrganisationsEinheitTestFactory.ID);

			assertThat(vorgangManagerAddress).isEqualTo(OrganisationsEinheitTestFactory.VORGANG_MANAGER_ADDRESS);
		}
	}
}