/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.router;

import java.util.Map;
import java.util.Optional;

import de.ozgcloud.eingang.router.GrpcClientsProperties.ClientProperty;
import de.ozgcloud.eingang.router.VorgangManagerListProperties.FallbackStrategy;
import de.ozgcloud.eingang.router.VorgangManagerListProperties.RoutingStrategy;

class VorgangManagerListPropertiesTestFactory {

	static final FallbackStrategy FALLBACK_STRATEGY = FallbackStrategy.DENY;
	static final String FUNDSTELLE_VORGANG_MANAGER_NAME = "fundstelle";
	static final String FUNDSTELLE_CHANNEL_NAME = "vorgang-manager-" + FUNDSTELLE_VORGANG_MANAGER_NAME;

	static final String ORGANISATIONSEINHEIT_ID = "123";
	static final String VORGANG_MANAGER_NAME = "kiel";
	static final String CHANNEL_NAME = "vorgang-manager-" + VORGANG_MANAGER_NAME;

	static final String ADDRESS = "127.0.0.1";

	static VorgangManagerListProperties createWithFundstelle() {
		var props = createForMultiRouting();
		props.setFallbackStrategy(Optional.of(FallbackStrategy.FUNDSTELLE));
		props.setFundstelleVorgangManagerName(Optional.of(FUNDSTELLE_VORGANG_MANAGER_NAME));

		return props;
	}

	static VorgangManagerListProperties createForMultiRouting() {
		var props = new VorgangManagerListProperties();
		props.setFallbackStrategy(Optional.of(FALLBACK_STRATEGY));
		props.setRoutingStrategy(RoutingStrategy.MULTI);
		props.setOrganisationseinheiten(Map.of(ORGANISATIONSEINHEIT_ID, VORGANG_MANAGER_NAME));
		props.setClientProperties(Optional.of(createClientProperties()));
		return props;
	}

	static VorgangManagerListProperties createForSingleRouting() {
		var props = new VorgangManagerListProperties();
		props.setRoutingStrategy(RoutingStrategy.SINGLE);
		props.setTargetVorgangManagerName(Optional.of(VORGANG_MANAGER_NAME));
		props.setClientProperties(Optional.of(createClientProperties()));

		return props;
	}

	static VorgangManagerListProperties createForZufiRouting() {
		var props = new VorgangManagerListProperties();
		props.setRoutingStrategy(RoutingStrategy.ZUFI);
		props.setFallbackStrategy(Optional.of(FallbackStrategy.DENY));

		return props;
	}

	static GrpcClientsProperties createClientProperties() {
		var property = new ClientProperty();
		property.setAddress(ADDRESS);
		var properties = new GrpcClientsProperties();
		properties.setClient(Map.of(CHANNEL_NAME, property));
		return properties;
	}

}
