/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.router.VorgangService;
import de.ozgcloud.eingang.semantik.enginebased.EngineBasedSemantikAdapter;
import de.ozgcloud.eingang.semantik.formbased.FormBasedSemantikAdapter;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
public class SemantikAdapter {

	@Autowired
	private List<EngineBasedSemantikAdapter> engineBasedAdapters;
	@Autowired
	private FormBasedSemantikAdapter formBasedAdapter;
	@Autowired
	private VorgangService vorgangService;

	public String processFormData(FormData formData) {
		formData = parseByEngineAdapter(formData);
		formData = parseByFormAdapter(formData);

		return vorgangService.createVorgang(formData);
	}

	private FormData parseByEngineAdapter(FormData formData) {
		List<EngineBasedSemantikAdapter> responsibleEngineAdapters = getResponsibleEngineAdapters(formData);
		for (var adapter : responsibleEngineAdapters) {
			try {
				formData = adapter.parseFormData(formData);
			} catch (Exception e) {
				LOG.error("beim Vorgang {} ist ein Fehler beim Parsing aufgetreten. Der Antrag wird trotzdem übernommen", formData.getId(), e);
			}
		}
		return formData;
	}

	List<EngineBasedSemantikAdapter> getResponsibleEngineAdapters(FormData formData) {
		return engineBasedAdapters.stream()
				.filter(adapter -> adapter.isResponsible(formData))
				.toList();
	}

	private FormData parseByFormAdapter(FormData formData) {
		return formBasedAdapter.parseFormData(formData);
	}
}
