/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.formbased;

import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.eingang.common.formdata.FormData;

@Service
public class FormBasedSemantikAdapter {

	@Autowired(required = false)
	private List<FormBasedMapper> mappers = Collections.emptyList();

	public FormData parseFormData(FormData formData) {

		return new FormDataProcessor().process(formData);
	}

	class FormDataProcessor {
		private FormData processedFormData;

		FormData process(FormData originalFormData) {
			processedFormData = originalFormData;
			mappers.stream()
					.filter(mapper -> mapper.isResponsible(processedFormData))
					.forEach(this::parseWithMapper);

			return processedFormData;
		}

		private void parseWithMapper(FormBasedMapper mapper) {
			processedFormData = mapper.parseFormData(processedFormData);
		}

	}

}
