/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.a12;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.Optional;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import com.fasterxml.jackson.databind.ObjectMapper;

import de.ozgcloud.common.binaryfile.TempFileUtils;
import de.ozgcloud.common.test.TestUtils;
import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormData.FormDataControl;
import de.ozgcloud.eingang.common.formdata.FormData.Representations;
import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;
import de.ozgcloud.eingang.common.formdata.IncomingFile;
import de.ozgcloud.eingang.common.formdata.IncomingFileTestFactory;

class A12FormDataMapperTest {

	@Spy
	@InjectMocks
	private A12FormDataMapper mapper;

	@Spy
	private ObjectMapper objectMapper = new ObjectMapper();

	@Nested
	class TestParseFormData {

		@Test
		void shouldGetFormDataFile() {
			var formData = buildInputFormData();

			mapper.parseFormData(formData);

			verify(mapper).getFormDataFile(same(formData));
		}
	}

	@Nested
	class TestGetFormDataFile {
		@Test
		void shouldReturnFile() {
			var inFile = mapper.getFormDataFile(buildInputFormData());

			assertThat(inFile).get().usingRecursiveComparison().ignoringFields("file").isEqualTo(buildFormDataInFile());
		}

		@Test
		void shouldCheckIfFound() {
			mapper.getFormDataFile(FormDataTestFactory.create());

			verify(mapper).logWarnIfEmpty(Optional.empty());
		}
	}

	private FormData buildInputFormData() {
		return FormDataTestFactory.createBuilder()
				.control(FormDataControl.builder()
						.representations(Optional.of(Representations.builder().primaryFormDataRepresentation("A12FormData.json").build())).build())
				.representation(buildFormDataInFile())
				.build();
	}

	private IncomingFile buildFormDataInFile() {
		return IncomingFileTestFactory.createBuilder()
				.contentType("application/json")
				.name("A12FormData.json")
				.file(TempFileUtils.writeTmpFile(TestUtils.loadFile("A12/a12FormData.json")))
				.build();
	}

	@Nested
	class TestReadEingang {

		@Test
		void shouldReadJson() {
			var file = TempFileUtils.writeTmpFile(TestUtils.loadFile("A12/a12FormData.json"));

			var result = mapper.readEingang(file);

			assertThat(result).isNotNull();
		}
	}

}
